##  Optional: Separate Queue for SAP LeanIX Integration
Use this feature when there is a possibility of long Script Action Processing times or rapid generation of events causing high volumes in the queues. Follow the [ServiceNow KB Article![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.servicenow.com%2Fdev.do%23%21%2Flearn%2Flearning-plans%2Frome%2Fservicenow_administrator%2Fapp_store_learnv2_automatingapps_rome_using_custom_queues_advanced_topic "https://developer.servicenow.com/dev.do#!/learn/learning-plans/rome/servicenow_administrator/app_store_learnv2_automatingapps_rome_using_custom_queues_advanced_topic") on the steps to be performed to create a separate queue.
